@@ -67,6 +67,7 @@ int sndpipe[2];
 int music=1,stereo=1;
 int sound_bufsiz;
 int have_joy=0;
+int autofire=0;
 
 int got_sigquit=0;
 
@@ -78,6 +79,8 @@ int current_colour=15;
 int scrnmode;
 #endif
 
+#define DELAY_AUTO_FIRE		5
+
 #define INIT_FRAMEDELAY		14285
 #define FRAME_DECR		8000
 
@@ -171,7 +174,7 @@ struct sample_tag
 
 
 #define GRIDDEPTH  100
-#define SHOTNUM     32
+#define SHOTNUM     64
 #define BADDIENUM   40
 #define STARNUM     10
 #define SHIELDLIFE  30
@@ -431,7 +434,7 @@ for(f=-4;f<=4;f++)
 
 vga_setcolor(3);
 centretextsize(90,bigwindow?2:1,
-	"(C) 1993-2000 Russell Marks for improbabledesigns");
+	"(C) 1993-2003 Russell Marks");
 
 vga_setcolor(10);
 centretextsize(375,bigwindow?6:3,
@@ -674,15 +677,24 @@ while(!quit && (!dead || (dead && gameover_count>0)))
     else
       if(keypress_pdc==0) waspdc=0;
       
-    if(keypress_fire && wasfire==0)
+    if(keypress_fire)
       {
-      wasfire=1;
-      addnewshot(xpos-3,ypos-2);                   /* fire */
-      addnewshot(xpos+3,ypos-2);
-      queuesam(PSHOT_CHANNEL,PSHOT_SAMPLE);
+      if(wasfire<=0)
+        {
+        if(autofire)
+          wasfire=DELAY_AUTO_FIRE;
+        else
+          wasfire=1;
+        addnewshot(xpos-3,ypos-2);                   /* fire */
+        addnewshot(xpos+3,ypos-2);
+        queuesam(PSHOT_CHANNEL,PSHOT_SAMPLE);
+        }
+      else
+        if(autofire)
+          wasfire--;
       }
     else
-      if(keypress_fire==0) wasfire=0;
+      wasfire=0;
 
     if(shield)
       shield--;
@@ -739,7 +751,7 @@ while(!quit && (!dead || (dead && gameover_count>0)))
           {
           /* speed up and loop back to start */
           looped=1;
-          framedelay-=FRAME_DECR;
+          if(framedelay==INIT_FRAMEDELAY) framedelay-=FRAME_DECR;
           wavenum=1;
           getnewwave(wavenum,looped);
           }
@@ -878,7 +890,8 @@ while(!quit && (!dead || (dead && gameover_count>0)))
   }
 
 /* end of game, save score */
-writescore(score);
+if(!autofire)
+  writescore(score);
 }
 
 
@@ -2030,6 +2043,11 @@ for(f=1;f<argc;f++)
   if(strcmp(argv[f],"-dbuf")==0) doublebuf=1;
   if(strcmp(argv[f],"-nomusic")==0) music=0;
   if(strcmp(argv[f],"-nosound")==0) sound=music=0;
+  if(strcmp(argv[f],"-autofire")==0)
+    {
+    autofire=1;
+    fprintf(stderr,"Note: `-autofire' disables hi-score recording.\n");
+    }
   }
 
 #ifndef USE_X
